@@ -3,3 +3,5 @@ from .slackbot import *
 from .sshbot import *
 from .telebot import *
 from .deploybot import *
+from .latexbot import *
+from .drivebot import *
